### R code from vignette source 'gevreg.Rnw'

###################################################
### code chunk number 1: preliminaries
###################################################
options(width = 70, prompt = "R> ", continue = "+  ")
library("gevreg")
library("ggplot2")


###################################################
### code chunk number 2: gevreg.Rnw:125-132
###################################################
library("gevreg")
library("ggplot2")
data("SnowAustria")
data("SnowAustriaGEV")
data("SnowAustriaMap")




###################################################
### code chunk number 3: gevreg.Rnw:137-143
###################################################
ggplot(SnowAustria,aes(lon,lat,color=alt)) + 
  geom_point(size = 4) + 
  annotate("label",
           x = c(11.3927,16.373),
           y = c(47.2672,48.203),
           label = c("Innsbruck","Wien"))


###################################################
### code chunk number 4: gevreg.Rnw:148-154
###################################################
ggplot(SnowAustria,aes(lon,lat,color=alt)) + 
  geom_point(size = 4) + 
  annotate("label",
           x = c(11.3927,16.373),
           y = c(47.2672,48.203),
           label = c("Innsbruck","Wien"))


###################################################
### code chunk number 5: gevreg.Rnw:162-165
###################################################
ggplot(SnowAustria,aes(hs)) + 
  geom_histogram(bins = 20) + 
  labs(x = "height of snow [cm]")


###################################################
### code chunk number 6: gevreg.Rnw:170-173
###################################################
ggplot(SnowAustria,aes(hs)) + 
  geom_histogram(bins = 20) + 
  labs(x = "height of snow [cm]")


###################################################
### code chunk number 7: gevreg.Rnw:181-183
###################################################
df <- cbind(SnowAustriaGEV,data.frame(lon = unique(SnowAustria$lon), alt = unique(SnowAustria$alt)))
plot(df)


###################################################
### code chunk number 8: gevreg.Rnw:188-191
###################################################
df <- cbind(SnowAustriaGEV,data.frame(lon = unique(SnowAustria$lon), 
                                      alt = unique(SnowAustria$alt)))
plot(df)


###################################################
### code chunk number 9: gevreg.Rnw:199-202
###################################################
SnowAustria$loc <- as.numeric(rep(SnowAustriaGEV$loc,
                                  each=nrow(SnowAustria)/
                                    length(levels(SnowAustria$station))))


###################################################
### code chunk number 10: gevreg.Rnw:207-209
###################################################
m0 <- gevreg(formula = hs ~ lon + alt | lat + alt + loc | lon, 
             data = SnowAustria, gev_params = SnowAustriaGEV, na.action = NULL)


###################################################
### code chunk number 11: gevreg.Rnw:214-215
###################################################
print(m0)


###################################################
### code chunk number 12: gevreg.Rnw:221-223
###################################################
m1 <- gevreg(formula = hs ~ 1 | lat + alt + loc | lon,
             data = SnowAustria, gev_params = SnowAustriaGEV, na.action = NULL)


###################################################
### code chunk number 13: gevreg.Rnw:228-229
###################################################
cbind(AIC(m0,m1),loglik=c(logLik(m0),logLik(m1)))


###################################################
### code chunk number 14: gevreg.Rnw:234-236
###################################################
SnowAustriaMap$loc <- predict(m0, type = "location", 
                              newdata = SnowAustriaMap, at=1-1/50)


###################################################
### code chunk number 15: gevreg.Rnw:241-264
###################################################
library("ggplot2")
library("colorspace")
values <- c(0,150,200,300,400)
colors <- diverge_hcl(length(values), 
                      h = c(260, 0), 
                      c = 100, 
                      l = c(30, 90), 
                      power = 0.7)
rl <- predict(m0, type = "quantile", newdata = SnowAustriaMap, at=1-1/50)
rl.fact <- cut(rl,values,values[-1])
ggplot(data.frame(SnowAustriaMap,rl.fact),aes(lon,lat,color=rl.fact,fill=rl.fact)) +
  geom_point(shape=22, size=2.75) +
  scale_color_manual(values = colors[1:length(values)],
                     limits = values,
                     breaks = rev(values[-1])) +
  scale_fill_manual(values = colors[1:length(values)],
                    limits = values,
                    breaks = rev(values[-1])) +
  guides(fill = guide_legend("50-year Snow Depth [cm]"),
         title.hjust = 0.5,
         color = FALSE) +
  annotate("point",x=11.393,y=47.267,shape=4,size=5,stroke=0.3) +
  annotate("text",x=11.4,y=47.267,label="Innsbruck",size=5,hjust=-0.2)


###################################################
### code chunk number 16: gevreg.Rnw:269-292
###################################################
library("ggplot2")
library("colorspace")
values <- c(0,150,200,300,400)
colors <- diverge_hcl(length(values), 
                      h = c(260, 0), 
                      c = 100, 
                      l = c(30, 90), 
                      power = 0.7)
rl <- predict(m0, type = "quantile", newdata = SnowAustriaMap, at=1-1/50)
rl.fact <- cut(rl,values,values[-1])
ggplot(data.frame(SnowAustriaMap,rl.fact),aes(lon,lat,color=rl.fact,fill=rl.fact)) +
  geom_point(shape=22, size=2.75) +
  scale_color_manual(values = colors[1:length(values)],
                     limits = values,
                     breaks = rev(values[-1])) +
  scale_fill_manual(values = colors[1:length(values)],
                    limits = values,
                    breaks = rev(values[-1])) +
  guides(fill = guide_legend("50-year Snow Depth [cm]"),
         title.hjust = 0.5,
         color = FALSE) +
  annotate("point",x=11.393,y=47.267,shape=4,size=5,stroke=0.3) +
  annotate("text",x=11.4,y=47.267,label="Innsbruck",size=5,hjust=-0.2)


